@@ -1,23 +1,5 @@
 package SQL::Translator::Filter::Globals;
 
-# -------------------------------------------------------------------
-# Copyright (C) 2002-2009 SQLFairy Authors
-#
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License as
-# published by the Free Software Foundation; version 2.
-#
-# This program is distributed in the hope that it will be useful, but
-# WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-# General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-# 02111-1307  USA
-# -------------------------------------------------------------------
-
 =head1 NAME
 
 SQL::Translator::Filter::Globals - Add global fields and indices to all tables.
@@ -39,7 +21,7 @@ SQL::Translator::Filter::Globals - Add global fields and indices to all tables.
                 }
             ],
             indices => [
-                { 
+                {
                     fields => 'modifed',
                 },
             ]
@@ -55,8 +37,8 @@ SQL::Translator::Filter::Globals - Add global fields and indices to all tables.
 =cut
 
 use strict;
-use vars qw/$VERSION/;
-$VERSION = '1.60';
+use warnings;
+our $VERSION = '1.59';
 
 sub filter {
     my $schema = shift;
@@ -147,22 +129,21 @@ __END__
 
 =head1 DESCRIPTION
 
-Adds global fields, indices and constraints to all tables in the
-schema.  The globals to add can either be defined in the filter args
-or using a _GLOBAL_ table (see below).
+Adds global fields, indices and constraints to all tables in the schema.
+The globals to add can either be defined in the filter args or using a _GLOBAL_
+table (see below).
 
-If a table already contains a field with the same name as a global
-then it is skipped for that table.
+If a table already contains a field with the same name as a global then it is
+skipped for that table.
 
 =head2 The _GLOBAL_ Table
 
-An alternative to using the args is to add a table called C<_GLOBAL_>
-to the schema and then just use the filter. Any fields and indices
-defined on this table will be added to all the tables in the schema
-and the _GLOBAL_ table removed.
+An alternative to using the args is to add a table called C<_GLOBAL_> to the
+schema and then just use the filter. Any fields and indices defined on this table
+will be added to all the tables in the schema and the _GLOBAL_ table removed.
 
-The name of the global can be changed using a C<global_table> arg to
-the filter.
+The name of the global can be changed using a C<global_table> arg to the
+filter.
 
 =head1 SEE ALSO
 
@@ -170,16 +151,16 @@ L<perl(1)>, L<SQL::Translator>
 
 =head1 BUGS
 
-Will generate duplicate indices if an index already exists on a table
-the same as one added globally.
+Will generate duplicate indices if an index already exists on a table the same
+as one added globally.
 
-Will generate duplicate constraints if a constraint already exists on
-a table the same as one added globally.
+Will generate duplicate constraints if a constraint already exists on a table
+the same as one added globally.
 
 =head1 TODO
 
-Some extra data values that can be used to control the global
-addition. e.g.  'skip_global'.
+Some extra data values that can be used to control the global addition. e.g.
+'skip_global'.
 
 =head1 AUTHOR
 
