@@ -1,23 +1,5 @@
 package SQL::Translator::Producer::TT::Base;
 
-# -------------------------------------------------------------------
-# Copyright (C) 2002-2009 SQLFairy Authors
-#
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License as
-# published by the Free Software Foundation; version 2.
-#
-# This program is distributed in the hope that it will be useful, but
-# WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-# General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-# 02111-1307  USA
-# -------------------------------------------------------------------
-
 =pod
 
 =head1 NAME
@@ -28,9 +10,10 @@ class.
 =cut
 
 use strict;
+use warnings;
 
-use vars qw[ $VERSION @EXPORT_OK ];
-$VERSION = '1.59';
+our @EXPORT_OK;
+our $VERSION = '1.59';
 
 use Template;
 use Data::Dumper;
@@ -149,8 +132,6 @@ sub tt_vars   { () };
 
 1;
 
-# -------------------------------------------------------------------
-
 =pod
 
 =head1 SYNOPSIS
@@ -262,7 +243,7 @@ The L<SQL::Translator> object.
 WARNING: This method is Experimental so may change!
 
 Called with the L<SQL::Translator::Schema> object and should return one (it
-doesn't have to be the same one) that will become the C<schema> varibale used 
+doesn't have to be the same one) that will become the C<schema> varibale used
 in the template.
 
 Gets called from tt_default_vars.
